==> jc-1.4.0.tar.gz: scm/primnode.h <==
// class scm.primnode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c6ba42ad8737f7d0 scm_primnode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_primnode_H_
#define _JC_scm_primnode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_primnode$sub_refs	_jc_scm_primnode$sub_refs;
typedef struct _jc_scm_primnode$sub_nonrefs	_jc_scm_primnode$sub_nonrefs;
typedef struct _jc_scm_primnode$refs	_jc_scm_primnode$refs;
typedef struct _jc_scm_primnode$nonrefs	_jc_scm_primnode$nonrefs;
typedef struct _jc_scm_primnode$object	_jc_scm_primnode$object;

typedef const struct _jc_scm_primnode$vmethods	_jc_scm_primnode$vmethods;
typedef const struct _jc_scm_primnode$vtable	_jc_scm_primnode$vtable;
typedef const struct _jc_scm_primnode$vtype	_jc_scm_primnode$vtype;

// Constructors
extern void _jc_scm_primnode$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_java_lang_Object$object *);

// Virtual methods
extern struct _jc_object *_jc_scm_primnode$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_scm_Env$object *);
extern struct _jc_java_lang_String$object *_jc_scm_primnode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_primnode$object *);

// Virtual method descriptors
extern _jc_method _jc_scm_primnode$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_primnode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_primnode$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_scm_Env$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_primnode$object *);
};

// Vtable
struct _jc_scm_primnode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_primnode$vmethods	scm_primnode;
};

// Vtype
struct _jc_scm_primnode$vtype {
	_jc_type			type;
	_jc_scm_primnode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_primnode$sub_refs {
	struct _jc_java_lang_Object$object	*val;
};

// Reference instance fields (object)
struct _jc_scm_primnode$refs {
    _jc_scm_primnode$sub_refs	scm_primnode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_primnode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_primnode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_primnode$sub_nonrefs	scm_primnode;
};

// Object instance structure
struct _jc_scm_primnode$object {
	_jc_scm_primnode$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_primnode$vtype	*vtype;
	_jc_scm_primnode$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_primnode$vtype _jc_scm_primnode$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_primnode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_primnode$class_object;

#endif	/* _JC_scm_primnode_H_ */

==> jc-1.4.6.tar.gz: scm/primnode.h <==
// class scm.primnode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class c6ba42ad8737f7d0 scm_primnode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_scm_primnode_H_
#define _JC_scm_primnode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_scm_Env$object;
struct _jc_scm_Obj$object;

// Typedefs
typedef struct _jc_scm_primnode$sub_refs	_jc_scm_primnode$sub_refs;
typedef struct _jc_scm_primnode$sub_nonrefs	_jc_scm_primnode$sub_nonrefs;
typedef struct _jc_scm_primnode$refs	_jc_scm_primnode$refs;
typedef struct _jc_scm_primnode$nonrefs	_jc_scm_primnode$nonrefs;
typedef struct _jc_scm_primnode$object	_jc_scm_primnode$object;

typedef const struct _jc_scm_primnode$vmethods	_jc_scm_primnode$vmethods;
typedef const struct _jc_scm_primnode$vtable	_jc_scm_primnode$vtable;
typedef const struct _jc_scm_primnode$vtype	_jc_scm_primnode$vtype;

// Constructors
extern void _jc_scm_primnode$method$_init$3fddd28dadb712ab(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_object *_jc_scm_primnode$method$eval$45e01bedb73fc9c4(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_scm_primnode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_scm_primnode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_scm_primnode$method_info$eval$45e01bedb73fc9c4;
extern _jc_method _jc_scm_primnode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_scm_primnode$vmethods {
	struct _jc_object	*(*eval$45e01bedb73fc9c4)(_jc_env *, struct _jc_scm_primnode$object *, struct _jc_scm_Env$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_scm_primnode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_scm_primnode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_scm_primnode$vmethods	scm_primnode;
};

// Vtype
struct _jc_scm_primnode$vtype {
	_jc_type			type;
	_jc_scm_primnode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_scm_primnode$sub_refs {
	struct _jc_java_lang_Object$object	*val;
};

// Reference instance fields (object)
struct _jc_scm_primnode$refs {
    _jc_scm_primnode$sub_refs	scm_primnode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_scm_primnode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_scm_primnode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_scm_primnode$sub_nonrefs	scm_primnode;
};

// Object instance structure
struct _jc_scm_primnode$object {
	_jc_scm_primnode$refs	refs[0];
	_jc_word		lockword;
	_jc_scm_primnode$vtype	*vtype;
	_jc_scm_primnode$nonrefs	nonrefs;
};

// Type structure
extern _jc_scm_primnode$vtype _jc_scm_primnode$type;

// Array types class info structures
_JC_DECL_ARRAYS(scm_primnode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_scm_primnode$class_object;

#endif	/* _JC_scm_primnode_H_ */
